%  fisat.m
% columns of isat_stats:
% 1=queries; 2=retrieves; 3=grows; 4=adds; 5=DI; 
% 6=cum. CPU in ISAT; 7=cum. CPU out of ISAT; 8=cum. wall clock time 
%
load isat_stats.out;
f = isat_stats;

figure(1)
subplot(2,2,1)
loglog( f(:,1), f(:,1:5) )
legend('query', 'retrieve', 'grow', 'add', 'replace' ,4 )
xlabel('queries')
ylabel('ISAT operations')

subplot(2,2,3)
semilogx( f(:,1), [f(:,1)./f(:,1) f(:,2)./f(:,1) f(:,3)./f(:,1) f(:,4)./f(:,1) f(:,5)./f(:,1) ])
legend('query', 'retrieve', 'grow', 'add', 'replace' ,3 )
xlabel('queries')
ylabel('ISAT operations as fraction')

subplot(2,2,2)
cpu_tot=f(:,6)+f(:,7);
loglog( f(:,1), [f(:,6:7) cpu_tot f(:,8)] )
legend('CPU in ISAT', 'CPU out of ISAT', 'CPU total', 'Wall clock', 4 )
xlabel('queries')
ylabel('CPU time (s)')

subplot(2,2,4)
semilogx( f(:,1), [f(:,6)./cpu_tot f(:,7)./cpu_tot] )
legend('in ISAT', 'out of ISAT', 'total', 3 )
xlabel('queries')
ylabel('Fraction of CPU time')

figure(2)
q = f(:,1);
a = f(:,4)+1;
t = f(:,6);
n = size(q,1);

subplot(1,2,1)
loglog( q, q./a, 'r-')
xlabel('queries')
ylabel('Retrieves per add')

subplot(1,2,2)
mus_per = zeros(size(q));
mus_per(2:n) = 1e6.*diff(t)./diff(q);
loglog( q, mus_per, 'r.' )
xlabel('queries')
ylabel('Time (mu s) per query')



n = size(f,1);
disp(' ')
disp(['queries (millions)      = ' num2str(f(n,1).*1e-6)] )
disp(['adds                    = ' num2str(f(n,4))] )
disp(['percentage retrieves    = ' num2str(100.*f(n,2)./f(n,1)) ])
disp(['percentage grows        = ' num2str(100.*f(n,3)./f(n,1)) ])
disp(['percentage adds         = ' num2str(100.*f(n,4)./f(n,1)) ])
disp(['percentage dir. eval.   = ' num2str(100.*f(n,5)./f(n,1)) ])
disp(['total CPU time (mins)   = ' num2str(cpu_tot(n)./60)])
disp(['percentage CPU in ISAT  = ' num2str(f(n,6).*100./cpu_tot(n) ) ] )
disp(['CPU per query (average) (micro s)       = ' num2str(f(n,6).*1e6./f(n,1) ) ] )
disp(['CPU per query (last interval) (micro s) = ' num2str(diff(f(n-1:n,6)).*1e6./diff(f(n-1:n,1)) ) ] )